/* _dict.cc 08/04/1998 00.20.18 */
/* squid.cc 28/08/2000 18.14.44 */
PUBLIC MODULE_squid::MODULE_squid (void);
PUBLIC void MODULE_squid::setmenu (DIALOG&dia, MENU_CONTEXT context);
PUBLIC int MODULE_squid::domenu (MENU_CONTEXT context, const char *key);
PUBLIC int MODULE_squid::dohtml (const char *key);
PUBLIC int MODULE_squid::execmain (int argc, char *argv[], bool);
/* squidedit.cc 06/01/2000 14.58.42 */
PUBLIC SQUID::SQUID (void);
PUBLIC int SQUID::write (void);
PUBLIC ITEM_COMMON::ITEM_COMMON (VIEWITEMS&items,
	 const char *_varname);
PUBLIC void ITEM_COMMON::save (VIEWITEMS&items);
PUBLIC void ITEM_COMMON::del (VIEWITEMS&items);
PUBLIC ITEM_INT::ITEM_INT (VIEWITEMS&items,
	 const char *_varname,
	 int defval);
PUBLIC void ITEM_INT::save (VIEWITEMS&items);
PUBLIC ITEM_STR::ITEM_STR (VIEWITEMS&items,
	 const char *_varname,
	 const char *defval);
PUBLIC void ITEM_STR::save (VIEWITEMS&items);
PUBLIC ITEM_BOOL::ITEM_BOOL (VIEWITEMS&items,
	 const char *_varname,
	 int defval);
PUBLIC void ITEM_BOOL::save (VIEWITEMS&items);
PUBLIC int SQUID::editdefaults (void);
PUBLIC int SQUID::editacl (void);
PUBLIC void SQUID::editmain (void);
